
polyfemos.back.interpreter.Interpreter
======================================

.. currentmodule:: polyfemos.back.interpreter

.. autoclass:: Interpreter
    :show-inheritance:

    

    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    

    
    .. rubric:: Public Methods

    
    .. automethod:: __init__
    .. automethod:: add_par
    .. automethod:: add_station
    .. automethod:: apply_async
    .. automethod:: call_func
    .. automethod:: close_and_join
    .. automethod:: data_coverage_image
    .. automethod:: define_flag
    .. automethod:: define_var
    .. automethod:: exit_scope
    .. automethod:: plot_ppsd
    .. automethod:: process_logs
    .. automethod:: readfile
    .. automethod:: replace_var
    .. automethod:: save_starttime
    .. automethod:: start
    .. automethod:: stop
    


    
    .. rubric:: Private Methods

    
    .. automethod:: _init_flags
    .. automethod:: _init_funcs_and_commands
    .. automethod:: _init_pool
    .. automethod:: _init_timedict
    

    

    


|